@@ -1,21 +1,26 @@
 package App::Git::Info;
-$App::Git::Info::VERSION = '0.0.2';
+$App::Git::Info::VERSION = '0.0.3';
+# ABSTRACT: Displays a summary of information about the git repository.
+
 use strict;
 use warnings;
 use 5.016;
 
 package main;
-$main::VERSION = '0.0.2';
+$main::VERSION = '0.0.3';
 use App::Rad;
 
 App::Rad->run;
 
 sub info
 {
-    return (  `git status` =~ s#\A(On branch \S+).*#⇒ $1#mrs . "\n"
+    my $ret =
+        (     `git status` =~ s#\A(On branch \S+).*#⇒ $1#mrs . "\n"
             . `git status -s`
             . "⇒ Remotes:\n"
             . `git remote -v` );
+    chomp $ret;
+    return $ret;
 }
 
 1;
@@ -28,14 +33,20 @@ __END__
 
 =head1 NAME
 
-App::Git::Info
+App::Git::Info - Displays a summary of information about the git repository.
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
+=head1 NAME
+
+=head1 VERSION
+
+version 0.0.3
+
     shlomif@telaviv1:~/conf/trunk$ git info info
     ⇒ On branch master
      M shlomif-settings/home-bin-executables/bin/git-i
@@ -44,14 +55,6 @@ version 0.0.2
     origin  git@github.com:shlomif/shlomif-computer-settings.git (push)
     shlomif@telaviv1:~/conf/trunk$
 
-=head1 NAME
-
-git-info - displays a summary of information about the git repository.
-
-=head1 VERSION
-
-version 0.0.2
-
 =head1 METHODS
 
 =head2 info
